@@ -13,8 +13,10 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Jenkins::API;
 use Term::ANSIColor qw/colored/;
+use File::ShareDir qw/dist_dir/;
+use Path::Tiny;
 
-our $VERSION = "0.001";
+our $VERSION = "0.002";
 
 has [qw/base_url api_key api_pass test/] => (
     is => 'rw',
@@ -24,6 +26,23 @@ has jenkins => (
     lazy => 1,
     builder => '_jenkins',
 );
+has colours => (
+    is       => 'rw',
+    required => 1,
+);
+has colour_map => (
+    is      => 'rw',
+    lazy    => 1,
+    default => sub {
+        my ($self) = @_;
+        return {
+            map {
+                ( $_ => [ split /\s+/, $self->colours->{$_} ] )
+            }
+            keys %{ $self->colours }
+        };
+    },
+);
 
 sub _jenkins {
     my ($self) = @_;
@@ -41,10 +60,6 @@ sub list {
     my $jenkins = $self->jenkins();
 
     my $data = $jenkins->_json_api([qw/api json/], { extra_params => { depth => 1 } });
-    my %colour_map = map {
-            ( $_ => [ split /\s+/, $opt->colors->{$_} ] )
-        }
-        keys %{ $opt->colors };
 
     for my $job (sort @{ $data->{jobs} }) {
         next if $query && $job->{name} !~ /$query/;
@@ -63,7 +78,7 @@ sub list {
         }
 
         # map "jenkins" colours to real colours
-        my $color = $colour_map{$job->{color}} || [$job->{color}];
+        my $color = $self->colour_map->{$job->{color}} || [$job->{color}];
 
         print colored($color, $name), " $extra\n";
     }
@@ -119,9 +134,24 @@ sub status {
 
     _error("Must start build with job name!\n") if !$job;
 
-    my $result = $jenkins->_json_api(['job', $job, 'api', 'json']);
+    my $result = $jenkins->_json_api(['job', $job, 'api', 'json'], { extra_params => { depth => 1 } });
 
-    print "$job\n";
+    my $color = $self->colour_map->{$result->{color}} || [$result->{color}];
+    print colored($color, $job), "\n";
+
+    if ($opt->verbose) {
+        for my $build (@{ $result->{builds} }) {
+            print "$build->{displayName}\t$build->{result}\t";
+            if ( $opt->verbose > 1 ) {
+                for my $action (@{ $build->{actions} }) {
+                    if ( $action->{lastBuiltRevision} ) {
+                        print $action->{lastBuiltRevision}{SHA1};
+                    }
+                }
+            }
+            print "\n";
+        }
+    }
 
     return;
 }
@@ -160,7 +190,7 @@ sub create {
     my ($self, $opt, $job, $config, @extra) = @_;
     my $jenkins = $self->jenkins();
 
-
+    $jenkins->create_job($job, $config);
 
     return;
 }
@@ -174,13 +204,78 @@ sub load {
     return;
 }
 
+sub enable {
+    my ($self, $opt, $query) = @_;
+
+    my $xsl = path(dist_dir('App-JenkinsCli'), 'enable.xsl');
+    $self->_xslt_actions($opt, $query, $xsl);
+
+    return;
+}
+
+sub disable {
+    my ($self, $opt, $query) = @_;
+
+    my $xsl = path(dist_dir('App-JenkinsCli'), 'disable.xsl');
+    $self->_xslt_actions($opt, $query, $xsl);
+
+    return;
+}
+
+sub change {
+    my ($self, $opt, $query, $xsl) = @_;
+
+    $self->_xslt_actions($opt, $query, $xsl);
+
+    return;
+}
+
+sub _xslt_actions {
+    my ($self, $opt, $query, $xsl) = @_;
+    require XML::LibXML;
+    require XML::LibXSLT;
+
+    my $xslt = XML::LibXSLT->new();
+    my $style_doc = XML::LibXML->load_xml(location => $xsl);
+    my $stylesheet = $xslt->parse_stylesheet($style_doc);
+
+    my $jenkins = $self->jenkins();
+
+    my $data = $jenkins->_json_api([qw/api json/], { extra_params => { depth => 0 } });
+
+    my %found;
+    for my $job (sort @{ $data->{jobs} }) {
+        next if $query && $job->{name} !~ /$query/;
+
+        my $config = $jenkins->project_config($job->{name});
+        my $dom = XML::LibXML->load_xml(string => $config);
+
+        my $results = $stylesheet->transform($dom);
+        my $output  = $stylesheet->output_as_bytes($results);
+
+        warn "Updating $job->{name}\n" if $opt->{verbose};
+        if ($opt->{test}) {
+            print "$output\n";
+        }
+        else {
+            my $success = $jenkins->set_project_config($job->{name}, $output);
+            if (!$success) {
+                warn "Error in updating $job->{name}\n";
+                last;
+            }
+        }
+    }
+
+    return;
+}
+
 1;
 
 __END__
 
 =head1 NAME
 
-App::JenkinsCli - Comamndline tool for interacting with Jenkins
+App::JenkinsCli - Command line tool for interacting with Jenkins
 
 =head1 VERSION
 
@@ -207,21 +302,29 @@ List all jobs, optionally filtering with C<$query>
 
 =head2 C<start ($opt, $job)>
 
-Start C<$jpb>
+Start C<$job>
 
 =head2 C<delete ($opt, $job)>
 
-Delete C<$jpb>
+Delete C<$job>
 
 =head2 C<status ($opt, $job)>
 
-Status of C<$jpb>
+Status of C<$job>
+
+=head2 C<enable ($opt, $job)>
+
+enable C<$job>
+
+=head2 C<disable ($opt, $job)>
+
+disable C<$job>
 
 =head2 C<conf ($opt, $job)>
 
 =head2 C<config ($opt, $job)>
 
-Show the config of C<$jpb>
+Show the config of C<$job>
 
 =head2 C<queue ($opt)>
 
@@ -231,10 +334,15 @@ Show the queue of running jobs
 
 Create a new Jenkins job
 
-=head2 load ($opt)>
+=head2 C<load ($opt)>
 
 Show the load stats for the server
 
+=head2 C<change ($opt, $query, $xsl)>
+
+Run the XSLT file (C<$xsl>) over each job matching C<$query> to generate a
+new config which is then sent back to Jenkins.
+
 =head1 ATTRIBUTES
 
 =over 4
@@ -259,6 +367,10 @@ Flag to not actually perform changes
 
 Internal L<Jenkins::API> object
 
+=item colours
+
+Mapping of Jenkins states to L<Term::ANSIColor>s
+
 =back
 
 =head1 DIAGNOSTICS
